@@ -24,14 +24,6 @@ describe 'nova::compute' do
         })
       end
 
-      it 'does not configures barbican service' do
-        is_expected.to contain_nova_config('key_manager/backend').with_value('nova.keymgr.conf_key_mgr.ConfKeyManager')
-        is_expected.to contain_nova_config('barbican/barbican_endpoint').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('barbican/barbican_api_version').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('barbican/auth_endpoint').with_value('<SERVICE DEFAULT>')
-        is_expected.to_not contain_package('cryptsetup').with( :ensure => 'present' )
-      end
-
       it 'does not configure vncproxy base url in nova.conf' do
         is_expected.to contain_nova_config('vnc/enabled').with_value(true)
         is_expected.to_not contain_nova_config('vnc/novncproxy_base_url')
@@ -43,7 +35,6 @@ describe 'nova::compute' do
       end
 
       it { is_expected.to contain_nova_config('DEFAULT/use_cow_images').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_nova_config('DEFAULT/mkisofs_cmd').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/force_raw_images').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/virt_mkfs').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/reserved_host_memory_mb').with_value('<SERVICE DEFAULT>') }
@@ -80,13 +71,13 @@ describe 'nova::compute' do
 
       it { is_expected.to contain_class('nova::availability_zone') }
 
-      it 'installs mkisofs package and sets config_drive_format' do
+      it 'installs genisoimage package and sets config_drive_format' do
         is_expected.to contain_nova_config('DEFAULT/config_drive_format').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_package(platform_params[:mkisofs_package]).with(
+        is_expected.to contain_package('genisoimage').with(
           :ensure => 'present',
         )
-        is_expected.to contain_package(platform_params[:mkisofs_package]).that_requires('Anchor[nova::install::begin]')
-        is_expected.to contain_package(platform_params[:mkisofs_package]).that_comes_before('Anchor[nova::install::end]')
+        is_expected.to contain_package('genisoimage').that_requires('Anchor[nova::install::begin]')
+        is_expected.to contain_package('genisoimage').that_comes_before('Anchor[nova::install::end]')
       end
 
       it 'configures nova pci_passthrough_whitelist' do
@@ -101,7 +92,6 @@ describe 'nova::compute' do
           :ensure_package                     => '2012.1-2',
           :vncproxy_host                      => '127.0.0.1',
           :use_cow_images                     => false,
-          :mkisofs_cmd                        => 'mkisofs',
           :force_raw_images                   => false,
           :virt_mkfs                          => 'windows=mkfs.ntfs --force --fast %(target)s',
           :reserved_host_memory               => '0',
@@ -174,7 +164,6 @@ describe 'nova::compute' do
       end
 
       it { is_expected.to contain_nova_config('DEFAULT/use_cow_images').with_value(false) }
-      it { is_expected.to contain_nova_config('DEFAULT/mkisofs_cmd').with_value('mkisofs') }
       it { is_expected.to contain_nova_config('DEFAULT/force_raw_images').with_value(false) }
       it { is_expected.to contain_nova_config('DEFAULT/virt_mkfs').with_value('windows=mkfs.ntfs --force --fast %(target)s') }
       it { is_expected.to contain_nova_config('DEFAULT/reserved_host_memory_mb').with_value('0') }
@@ -206,7 +195,7 @@ describe 'nova::compute' do
 
       it 'configures nova config_drive_format to vfat' do
         is_expected.to contain_nova_config('DEFAULT/config_drive_format').with_value('vfat')
-        is_expected.to_not contain_package(platform_params[:mkisofs_package]).with(
+        is_expected.to_not contain_package('genisoimage').with(
           :ensure => 'present',
         )
       end
@@ -462,29 +451,16 @@ describe 'nova::compute' do
       let (:facts) do
         facts.merge!(OSDefaults.get_facts())
       end
-      case facts[:osfamily]
-      when 'Debian'
-        let (:platform_params) do
+
+      let (:platform_params) do
+        case facts[:osfamily]
+        when 'Debian'
           { :nova_compute_package => 'nova-compute',
-            :nova_compute_service => 'nova-compute',
-            :mkisofs_package => 'genisoimage' }
-        end
-      when 'RedHat'
-        let (:platform_params) do
+            :nova_compute_service => 'nova-compute' }
+        when 'RedHat'
           { :nova_compute_package => 'openstack-nova-compute',
             :nova_compute_service => 'openstack-nova-compute' }
         end
-        if facts[:operatingsystemmajrelease] > '8'
-          before do
-            platform_params.merge!({
-              :mkisofs_package => 'xorriso' })
-          end
-        else
-          before do
-            platform_params.merge!({
-              :mkisofs_package => 'genisoimage' })
-          end
-        end
       end
       it_behaves_like 'nova-compute'
     end
